*************
API reference
*************

.. autosummary::
   :toctree: api

   parametrize_from_file
   parametrize_from_file.parametrize
   parametrize_from_file.fixture
   parametrize_from_file.Namespace
   parametrize_from_file.cast
   parametrize_from_file.defaults
   parametrize_from_file.error
   parametrize_from_file.error_or
   parametrize_from_file.star
   parametrize_from_file.add_loader
   parametrize_from_file.drop_loader
   parametrize_from_file.load_parameters
   parametrize_from_file.ConfigError
